jacinle.random.rng
==================

.. automodule:: jacinle.random.rng

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      JacRandomState
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      gen_rng
      gen_seed
      get_default_rng
      reset_global_seed
      seed
      with_seed
   
   

   
   
   








.. rubric:: Class JacRandomState
.. autoclass:: JacRandomState
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: gen_rng

.. autofunction:: gen_seed

.. autofunction:: get_default_rng

.. autofunction:: reset_global_seed

.. autofunction:: seed

.. autofunction:: with_seed


